summaryrefslogtreecommitdiffstats
path: root/gdb/gnu-regex.c
diff options
context:
space:
mode:
authorJason Molenda <jmolenda@apple.com>1998-06-10 18:54:59 +0000
committerJason Molenda <jmolenda@apple.com>1998-06-10 18:54:59 +0000
commita4122443afc9130bc65910974728b468b217d3c2 (patch)
tree6be735619f63b8a3fb9c074dfba6ce826aedcf36 /gdb/gnu-regex.c
parent8c2de2aa3372d27f5847aaceb8ad16aed7880e81 (diff)
downloadppe42-binutils-a4122443afc9130bc65910974728b468b217d3c2.tar.gz
ppe42-binutils-a4122443afc9130bc65910974728b468b217d3c2.zip
Wed Jun 10 11:53:42 1998 Jason Molenda (crash@bugshack.cygnus.com)
* gnu-regex.c: Include "gnu-regex.h", not "regex.h".
Diffstat (limited to 'gdb/gnu-regex.c')
-rw-r--r--gdb/gnu-regex.c13
1 files changed, 7 insertions, 6 deletions
diff --git a/gdb/gnu-regex.c b/gdb/gnu-regex.c
index 770df3ed33..424f624759 100644
--- a/gdb/gnu-regex.c
+++ b/gdb/gnu-regex.c
@@ -44,7 +44,7 @@
#if defined STDC_HEADERS && !defined emacs
# include <stddef.h>
#else
/* We need this for `regex.h', and perhaps for the Emacs include files. */
# include <sys/types.h>
#endif
@@ -204,7 +204,8 @@ init_syntax_once ()
#endif /* not emacs */
/* Get the interface, including the syntax bits. */
-#include "regex.h"
+/* CYGNUS LOCAL: call it gnu-regex.h, not regex.h, to avoid name conflicts */
+#include "gnu-regex.h"
/* isalpha etc. are used for the character classes. */
#include <ctype.h>
@@ -978,7 +979,7 @@ reg_syntax_t re_syntax_options;
different, incompatible syntaxes.
The argument SYNTAX is a bit mask comprised of the various bits
- defined in regex.h. We return the old syntax. */
+ defined in gnu-regex.h. We return the old syntax. */
reg_syntax_t
re_set_syntax (syntax)
@@ -1000,7 +1001,7 @@ weak_alias (__re_set_syntax, re_set_syntax)
#endif
/* This table gives an error message for each of the error codes listed
- in regex.h. Obviously the order here has to be same as there.
+ in gnu-regex.h. Obviously the order here has to be same as there.
POSIX doesn't require that we do anything for REG_NOERROR,
but why not be nice? */
@@ -1796,7 +1797,7 @@ static boolean group_in_compile_stack _RE_ARGS ((compile_stack_type
regnum_t regnum));
/* `regex_compile' compiles PATTERN (of length SIZE) according to SYNTAX.
- Returns one of error codes defined in `regex.h', or zero for success.
+ Returns one of error codes defined in `gnu-regex.h', or zero for success.
Assumes the `allocated' (and perhaps `buffer') and `translate'
fields are set in BUFP on entry.
@@ -5583,7 +5584,7 @@ re_exec (s)
routine will report only success or failure, and nothing about the
registers.
- It returns 0 if it succeeds, nonzero if it doesn't. (See regex.h for
+ It returns 0 if it succeeds, nonzero if it doesn't. (See gnu-regex.h for
the return codes and their meanings.) */
int
OpenPOWER on IntegriCloud
@@ -44,7 +44,7 @@
# include <stddef.h>
#else
-/* We need this for `regex.h', and perhaps for the Emacs include files. */
+/* We need this for `gnu-regex.h', and perhaps for the Emacs include files. */
# include <sys/types.h>
#endif